==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/modules/EmailTemplates/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
/*********************************************************************************

 * Description: Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'LBL_ADD_ANOTHER_FILE'		=> 'Add Another File',
	'LBL_ADD_DOCUMENT'			=> 'Add a Sugar Document',
	'LBL_ADD_FILE'				=> 'Add a file',
	'LBL_ATTACHMENTS'			=> 'Attachments',
	'LBL_BODY'					=> 'Body:',
	'LBL_CLOSE'					=> 'Close:',
	'LBL_COLON'					=> ':',
	'LBL_CONTACT_AND_OTHERS'	=> 'Contact/Lead/Target',
	'LBL_DESCRIPTION'			=> 'Description:',
	'LBL_EDIT_ALT_TEXT'			=> 'Edit Plain Text',
	'LBL_EMAIL_ATTACHMENT'		=> 'Email Attachment',
	'LBL_HTML_BODY'				=> 'HTML Body',
	'LBL_INSERT_VARIABLE'		=> 'Insert Variable:',
	'LBL_INSERT_URL_REF'		=> 'Insert URL Reference',
	'LBL_INSERT_TRACKER_URL'	=> 'Insert Tracker URL:',
	'LBL_INSERT'				=> 'Insert',
	'LBL_LIST_DATE_MODIFIED'	=> 'Last Modified',
	'LBL_LIST_DESCRIPTION'		=> 'Description',
	'LBL_LIST_FORM_TITLE'		=> 'Email Templates List',
	'LBL_LIST_NAME'				=> 'Name',
	'LBL_MODULE_NAME'			=> 'Email Templates',
	'LBL_MODULE_TITLE'			=> 'Email Templates: Home',
	'LBL_NAME'					=> 'Name:',
	'LBL_NEW_FORM_TITLE'		=> 'Create Email Template',
	'LBL_PUBLISH'				=> 'Publish:',
	'LBL_RELATED_TO'			=> 'Related To:',
	'LBL_SEARCH_FORM_TITLE'		=> 'Email Templates Search',
	'LBL_SHOW_ALT_TEXT'			=> 'Show Plain Text',
	'LBL_SUBJECT'				=> 'Subject:',
    'LBL_SUGAR_DOCUMENT'        => 'Sugar Document',
	'LBL_TEAMS'					=> 'Teams:',
	'LBL_TEAMS_LINK'			=> 'Teams',
	'LBL_TEXT_BODY'				=> 'Text Body',
	'LBL_USERS'					=> 'Users',

	'LNK_ALL_EMAIL_LIST'		=> 'All Emails',
	'LNK_ARCHIVED_EMAIL_LIST'	=> 'Archived Emails',
	'LNK_CHECK_EMAIL'			=> 'Check Mail',
	'LNK_DRAFTS_EMAIL_LIST'		=> 'All Drafts',
	'LNK_EMAIL_TEMPLATE_LIST'	=> 'Email Templates',
	'LNK_IMPORT_NOTES'			=> 'Import Notes',
	'LNK_NEW_ARCHIVE_EMAIL'		=> 'Create Archived Email',
	'LNK_NEW_EMAIL_TEMPLATE'	=> 'Create Email Template',
	'LNK_NEW_EMAIL'				=> 'Archive Email',
	'LNK_NEW_SEND_EMAIL'		=> 'Compose Email',
	'LNK_SENT_EMAIL_LIST'		=> 'Sent Emails',
	'LNK_VIEW_CALENDAR'			=> 'Today',
	// for Inbox
	'LBL_NEW'					=> 'New',
	'LNK_CHECK_MY_INBOX'		=> 'Check My Mail',
	'LNK_GROUP_INBOX'			=> 'Group Inbox',
	'LNK_MY_ARCHIVED_LIST'		=> 'My Archives',
	'LNK_MY_DRAFTS'				=> 'My Drafts',
	'LNK_MY_INBOX'				=> 'My Email',
	'LBL_LIST_BASE_MODULE'		=> 'Base Module:',
    'LBL_TEXT_ONLY'             => 'Text Only',
    'LBL_SEND_AS_TEXT'          => 'Send Text Only',
    'LBL_ACCOUNT'               => 'Account',
    'LBL_BASE_MODULE'=>'Base Module',
    'LBL_FROM_NAME'=>'From Name',
    'LBL_PLAIN_TEXT'=>'Plain Text',
    'LBL_CREATED_BY'=>'Created By',
    'LBL_FROM_ADDRESS'=>'From Address',
    'LBL_PUBLISHED'=>'Published',
    'LBL_ACTIVITIES_REPORTS' 	=> 'Activities Report',    
    
);
?>

==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/modules/EmailTemplates/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description: Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'LBL_ADD_ANOTHER_FILE'		=> 'Add Another File',
	'LBL_ADD_DOCUMENT'			=> 'Add a Sugar Document',
	'LBL_ADD_FILE'				=> 'Add a file',
	'LBL_ATTACHMENTS'			=> 'Attachments',
	'LBL_BODY'					=> 'Body:',
	'LBL_CLOSE'					=> 'Close:',
	'LBL_COLON'					=> ':',
	'LBL_CONTACT_AND_OTHERS'	=> 'Contact/Lead/Target',
	'LBL_DESCRIPTION'			=> 'Description:',
	'LBL_EDIT_ALT_TEXT'			=> 'Edit Plain Text',
	'LBL_EMAIL_ATTACHMENT'		=> 'Email Attachment',
	'LBL_HTML_BODY'				=> 'HTML Body',
	'LBL_INSERT_VARIABLE'		=> 'Insert Variable:',
	'LBL_INSERT_URL_REF'		=> 'Insert URL Reference',
	'LBL_INSERT_TRACKER_URL'	=> 'Insert Tracker URL:',
	'LBL_INSERT'				=> 'Insert',
	'LBL_LIST_DATE_MODIFIED'	=> 'Last Modified',
	'LBL_LIST_DESCRIPTION'		=> 'Description',
	'LBL_LIST_FORM_TITLE'		=> 'Email Templates List',
	'LBL_LIST_NAME'				=> 'Name',
	'LBL_MODULE_NAME'			=> 'Email Templates',
	'LBL_MODULE_TITLE'			=> 'Email Templates: Home',
	'LBL_NAME'					=> 'Name:',
	'LBL_NEW_FORM_TITLE'		=> 'Create Email Template',
	'LBL_PUBLISH'				=> 'Publish:',
	'LBL_RELATED_TO'			=> 'Related To:',
	'LBL_SEARCH_FORM_TITLE'		=> 'Email Templates Search',
	'LBL_SHOW_ALT_TEXT'			=> 'Show Plain Text',
	'LBL_SUBJECT'				=> 'Subject:',
    'LBL_SUGAR_DOCUMENT'        => 'Sugar Document',
	'LBL_TEAMS'					=> 'Teams:',
	'LBL_TEAMS_LINK'			=> 'Teams',
	'LBL_TEXT_BODY'				=> 'Text Body',
	'LBL_USERS'					=> 'Users',

	'LNK_ALL_EMAIL_LIST'		=> 'All Emails',
	'LNK_ARCHIVED_EMAIL_LIST'	=> 'Archived Emails',
	'LNK_CHECK_EMAIL'			=> 'Check Mail',
	'LNK_DRAFTS_EMAIL_LIST'		=> 'All Drafts',
	'LNK_EMAIL_TEMPLATE_LIST'	=> 'View Email Templates',
	'LNK_IMPORT_NOTES'			=> 'Import Notes',
	'LNK_NEW_ARCHIVE_EMAIL'		=> 'Create Archived Email',
	'LNK_NEW_EMAIL_TEMPLATE'	=> 'Create Email Template',
	'LNK_NEW_EMAIL'				=> 'Archive Email',
	'LNK_NEW_SEND_EMAIL'		=> 'Compose Email',
	'LNK_SENT_EMAIL_LIST'		=> 'Sent Emails',
	'LNK_VIEW_CALENDAR'			=> 'Today',
	// for Inbox
	'LBL_NEW'					=> 'New',
	'LNK_CHECK_MY_INBOX'		=> 'Check My Mail',
	'LNK_GROUP_INBOX'			=> 'Group Inbox',
	'LNK_MY_ARCHIVED_LIST'		=> 'My Archives',
	'LNK_MY_DRAFTS'				=> 'My Drafts',
	'LNK_MY_INBOX'				=> 'My Email',
	'LBL_LIST_BASE_MODULE'		=> 'Base Module:',
    'LBL_TEXT_ONLY'             => 'Text Only',
    'LBL_SEND_AS_TEXT'          => 'Send Text Only',
    'LBL_ACCOUNT'               => 'Account',
    'LBL_BASE_MODULE'=>'Base Module',
    'LBL_FROM_NAME'=>'From Name',
    'LBL_PLAIN_TEXT'=>'Plain Text',
    'LBL_CREATED_BY'=>'Created By',
    'LBL_FROM_ADDRESS'=>'From Address',
    'LBL_PUBLISHED'=>'Published',
    'LBL_ACTIVITIES_REPORTS' 	=> 'Activities Report',    
    'LNK_VIEW_MY_INBOX' => 'View My Email',
	'LBL_ASSIGNED_TO_ID' => 'Assigned To',
);
?>
